@@ -8,7 +8,6 @@
 from __future__ import print_function
 from Bio.SeqRecord import SeqRecord
 from Bio.Seq import Seq
-from Bio.Data import IUPACData
 from biasaway.utils import GC, dinuc_count, IUPAC_DINUC
 from ushuffle import shuffle, set_seed
 
@@ -28,12 +27,12 @@ def generate_sequences(seqs, kmer, winlen, step, nfold, random_seed):
     bg_lengths = []
     dinuc = [0] * len(IUPAC_DINUC)
     for record in seqs:
+        record.seq = record.seq.upper()
         seq = record.seq.__str__()
         descr = "Background sequence for {0:s}".format(record.name, cpt)
         for n in range(0, nfold):
             new_sequence = shuffle_window(seq, kmer, winlen, step)
-            new_seq = SeqRecord(Seq(new_sequence,
-                                    IUPACData.ambiguous_dna_letters),
+            new_seq = SeqRecord(Seq(new_sequence),
                                 id="background_seq_{0:d}".format(cpt),
                                 description=descr)
             print(new_seq.format("fasta"), end='')
